# ####
# INFO 
# ####
#
# longtext.tcl v1.3 (Dec 01, 2007)
#
# ##########
# DESCRITION
# ##########
# 
# This script ban those channel users who use excessive characters in a single line,
# also lock the channel (moderate i.e. +m) to protect the channel from the same repeating offence,
# as seen in the message flood that clones display their messages again and again.
#
# ########
# FEATURES
# ########
# 
# You can set channel lock modes, bansmask type, voice immunity, multiple modes (+mi/+mr) etc. depends on your channel situation,
# By default, this script is set to 250 characters with lock time of 5 seconds and ban time of 5 minutes.
# you can change the settings as per your desire which is suitable for your channel.
#
# ############
# INSTALLATION
# ############
#
# * First unzip zipped file i.e. longtext.zip file 
# * Put longtext.tcl file in your eggdrop "/scripts" folder
# * Add a link at the bottom of your eggdrop's .CONF file
#
#   	   source scripts/longtext.tcl
#
# * Save your bot's configuration
# * RESTART your bot -OR- do .rehash from the partyline (DCC) to load the tcl.
#
# #######
# UPDATES
# #######
# 
# v1.0 - 01/03/2005 - Initial Release.
# v1.1 - 06/05/2005 - Following;
# 		            o Channel Activation       
# 		            o Voice Users Protection  
#	                  o Banmask Types      
#  		            o Lock Modes      
# 		            o KICK/BAN Reason
# v1.2 - 28/08/2005 - Following;
#                       o Added Action Text Protection 
# v1.3 - 01/12/2007 - Following;
#                       o Added Unban Timer 
#
# #######
# CONTACT
# #######
#
# Any suggestions, comments, questions or bugs,
# feel free to email me at:
#
#			fyre_tcls@yahoo.com
#
# fyre @ #Eggdrop & #RO-TCL
# On Undernet IRC Network
#
# #########
# DOWNLOADS
# #########
#
# This Script and other good TCL Scripts can be found on:
#
# * http://www.egghelp.org/
# * http://www.tclscript.com/
#
# -REGARDS-

########################
#- Channel Activation -#
########################

# DCC/Partyline :  n|n .chanset   Use .chanset to activate the protections for the particular channel or not.
#       Example : .chanset #mychan1 +longtxt
#                 .chanset #mychan2 -longtxt

######################
#- Characters Limit -#
######################

# Set the maximum charaters which is allow to broadcast in a Line.
set longline(txt_len) 250

###############
#- Lock Mode -#
###############

# Set channel modes which you want to be used for locking,
# Leave blank "" if you dont like to set modes.
set longline(modes) "m"

##############
#- BAN Type -#
##############

# Set the banmask type to use in banning the IPs  
# Currently BAN Type is set to 1 (*!*@some.domain.com),
# BAN Types are given below;
# 1 - *!*@some.domain.com 
# 2 - *!*@*.domain.com
# 3 - *!*ident@some.domain.com
# 4 - *!*ident@*.domain.com
# 5 - *!*ident*@some.domain.com
# 6 - *nick*!*@*.domain.com
# 7 - *nick*!*@some.domain.com
# 8 - nick!ident@some.domain.com
# 9 - nick!ident@*.host.com
set lt_btype 1


###############
#- Lock Time -#
###############

# Set the unlock time (in seconds), How much time it takes to do -m after the Long Text detection.
set longline(unlock) 5

#####################
#- Kick/BAN Reason -#
#####################

# Set kick/ban reason here.
set longline(reason) "Long Text Detected"

#####################
#- Voice Exemption -#
#####################

# Voice Immune [0/1]:Set to 1 if you want to protect users who are voiced,
# -OR- Set to 0 to punish everyone who broadcast longline in the channel.
# (NOTE: This script does not kick any Operator(s).)
set longline(vxmpt) 1

##############
#- BAN Time -#
##############

# Set time period (in minutes), How much time it takes to unban punished user.
set longline(ub) 5


########################################################
#- Don't edit below unless you know what you're doing -#
########################################################

setudef flag longtxt
bind pubm - * longline:pubm
bind ctcp - ACTION longline:action

proc longline:pubm {nick uhost hand chan txt} {
  global longline
  if {![channel get $chan longtxt]} { return 0 }
  if {($longline(vxmpt) == 1) && [isvoice $nick $chan]} { return 0 }
  if {![botisop $chan] || [isbotnick $nick] || [isop $nick $chan] || [matchattr $hand b] || [matchattr $hand f|f $chan] || [matchattr $hand mo|mo $chan]} {
    return
  }
  if {[string length $txt] >= $longline(txt_len)} {
    set banmask [lt:banmask $uhost $nick]
    putquick "MODE $chan +$longline(modes)b $banmask" 
    putserv "KICK $chan $nick :$longline(reason)"
    utimer $longline(unlock) [list putserv "MODE $chan -$longline(modes)"]
    timer $longline(ub) [list putserv "MODE $chan -b $banmask"]
  }
}
proc longline:action {nick uhost hand chan keyword arg} {
 if {[isbotnick [lindex [split $chan "@"] 0]] || [lindex [split $chan "@"] 1] != ""} {return 0}
 longline:pubm $nick $uhost $hand $chan $arg
}
proc lt:banmask {uhost nick} {
 global lt_btype
  switch -- $lt_btype {
   1 { set banmask "*!*@[lindex [split $uhost @] 1]" }
   2 { set banmask "*!*@[lindex [split [maskhost $uhost] "@"] 1]" }
   3 { set banmask "*!*$uhost" }
   4 { set banmask "*!*[lindex [split [maskhost $uhost] "!"] 1]" }
   5 { set banmask "*!*[lindex [split $uhost "@"] 0]*@[lindex [split $uhost "@"] 1]" }
   6 { set banmask "*$nick*!*@[lindex [split [maskhost $uhost] "@"] 1]" }
   7 { set banmask "*$nick*!*@[lindex [split $uhost "@"] 1]" }
   8 { set banmask "$nick![lindex [split $uhost "@"] 0]@[lindex [split $uhost @] 1]" }
   9 { set banmask "$nick![lindex [split $uhost "@"] 0]@[lindex [split [maskhost $uhost] "@"] 1]" }
   default { set banmask "*!*@[lindex [split $uhost @] 1]" }
   return $banmask
  }
}

####################################################
putlog "LOADED: Long Text Protection (v1.3) by fyre"
####################################################